@@ -1,29 +1,37 @@
 <?php
 /**
- * $Horde: turba/delete.php,v 1.29.4.2 2005/03/05 23:15:55 chuck Exp $
+ * $Horde: turba/delete.php,v 1.29.4.8 2009-01-06 15:27:38 jan Exp $
  *
- * Copyright 2000-2005 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
+ *
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 @define('TURBA_BASE', dirname(__FILE__));
 require_once TURBA_BASE . '/lib/base.php';
 
 $source = Util::getFormData('source');
-$driver = &Turba_Driver::singleton($source, $cfgSources[$source]);
-
 $key = Util::getFormData('key');
-if (!is_a($result = $driver->delete($key), 'PEAR_Error')) {
-    if (!empty($_SESSION['turba_search_results'])) {
-        require_once TURBA_BASE . '/lib/List.php';
-        require_once TURBA_BASE . '/lib/Object.php';
-        $list = Turba_List::unserialize($_SESSION['turba_search_results']);
-        $list->remove($key);
-        $_SESSION['turba_search_results'] = $list->serialize();
-    }
+$driver = &Turba_Driver::singleton($source);
 
+if ($conf['documents']['type'] != 'none') {
+    $object = $driver->getObject($key);
+    if (is_a($object, 'PEAR_Error')) {
+        $notification->push($object->getMessage(), 'horde.error');
+        header('Location: ' . Horde::applicationUrl($prefs->getValue('initial_page'), true));
+        exit;
+    }
+    if (is_a($deleted = $object->deleteFiles(), 'PEAR_Error')) {
+        $notification->push($deleted, 'horde.error');
+        header('Location: ' . Horde::applicationUrl($prefs->getValue('initial_page'), true));
+        exit;
+    }
+}
+
+if (!is_a($result = $driver->delete($key), 'PEAR_Error')) {
     header('Location: ' . Util::getFormData('url', Horde::url($prefs->getValue('initial_page'), true)));
     exit;
 }
