@@ -3,7 +3,7 @@
  * Turba directory driver implementation for PHP's PEAR database abstraction
  * layer.
  *
- * $Horde: turba/lib/Driver/sql.php,v 1.59.10.31 2009/07/10 00:37:32 mrubinsk Exp $
+ * $Horde: turba/lib/Driver/sql.php,v 1.59.10.34 2010-02-13 19:23:21 mrubinsk Exp $
  *
  * @author  Jon Parise <jon@csh.rit.edu>
  * @package Turba
@@ -306,6 +306,14 @@ class Turba_Driver_sql extends Turba_Driver {
         return true;
     }
 
+    /**
+     * @see turba/lib/Turba_Driver#_canAdd()
+     */
+    function _canAdd()
+    {
+        return true;
+    }
+
     /**
      * Deletes the specified object from the SQL database.
      */
@@ -331,7 +339,7 @@ class Turba_Driver_sql extends Turba_Driver {
     /**
      * Deletes all contacts from a specific address book.
      *
-     * @return boolean  True if the operation worked.
+     * @return mixed  True if the operation worked, PEAR_Error on error
      */
     function _deleteAll($sourceName = null)
     {
@@ -339,19 +347,44 @@ class Turba_Driver_sql extends Turba_Driver {
             return PEAR::raiseError('permission denied');
         }
 
-        $query = 'DELETE FROM ' . $this->_params['table'] . ' WHERE owner_id = ?';
-
+        /* Get owner id */
         if (empty($sourceName)) {
             $values = array(Auth::getAuth());
         } else {
             $values = array($sourceName);
         }
 
-        /* Log the query at a DEBUG log level. */
+        /* Need a list of UIDs so we can notify History */
+        $query = 'SELECT '. $this->map['__uid'] . ' FROM ' . $this->_params['table'] . ' WHERE owner_id = ?';
+        Horde::logMessage('SQL query by Turba_Driver_sql::_deleteAll(): ' . $query,
+                          __FILE__, __LINE__, PEAR_LOG_DEBUG);
+        $ids = $this->_write_db->query($query, $values);
+        if (is_a($ids, 'PEAR_Error')) {
+            return $ids;
+        }
+
+        /* Do the deletion */
+        $query = 'DELETE FROM ' . $this->_params['table'] . ' WHERE owner_id = ?';
         Horde::logMessage('SQL query by Turba_Driver_sql::_deleteAll(): ' . $query,
                           __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
-        return $this->_write_db->query($query, $values);
+        $result = $this->_write_db->query($query, $values);
+        if (is_a($result, 'PEAR_Error')) {
+            return $result;
+        }
+
+        /* Update Horde_History */
+        require_once 'Horde/History.php';
+        $history = &Horde_History::singleton();
+        while($ids->fetchInto($row)) {
+            // This is slightly hackish, but it saves us from having to create
+            // and save an array of Turba_Objects before we delete them, just to
+            // be able to calculate this using Turba_Object#getGuid
+            $guid = 'turba:' . $this->getName() . ':' . $row[0];
+            $history->log($guid, array('action' => 'delete'), true);
+        }
+
+        return true;
     }
 
     /**
