@@ -3,7 +3,7 @@
  * The Turba_List:: class provides an interface for dealing with a
  * list of Turba_Objects.
  *
- * $Horde: turba/lib/List.php,v 1.41.10.8 2008/08/28 21:24:04 chuck Exp $
+ * $Horde: turba/lib/List.php,v 1.41.10.9 2010-08-14 19:20:40 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@csh.rit.edu>
@@ -149,7 +149,7 @@ class Turba_List {
      *
      * @return integer  Comparison of the two field values.
      */
-    function cmp($a, $b)
+    function cmp(&$a, &$b)
     {
         foreach ($this->_usortCriteria as $field) {
             // Set the comparison type based on the type of attribute we're
@@ -166,8 +166,7 @@ class Turba_List {
             }
 
             $method = 'cmp_' . $usortType;
-            $result = $this->$method($a->getValue($field['field']),
-                                     $b->getValue($field['field']));
+            $result = $this->$method($a, $b, $field['field']);
             if (!$field['ascending']) {
                 $result = -$result;
             }
@@ -178,18 +177,22 @@ class Turba_List {
         return 0;
     }
 
-    function cmp_text($a, $b)
+    function cmp_text(&$a, &$b, $field)
     {
-        $acmp = String::lower($a, true);
-        $bcmp = String::lower($b, true);
+        if (!isset($a->sortValue[$field])) {
+            $a->sortValue[$field] = String::lower($a->getValue($field), true);
+        }
+        if (!isset($b->sortValue[$field])) {
+            $b->sortValue[$field] = String::lower($b->getValue($field), true);
+        }
 
         // Use strcoll for locale-safe comparisons.
-        return strcoll($acmp, $bcmp);
+        return strcoll($a->sortValue[$field], $b->sortValue[$field]);
     }
 
-    function cmp_int($a, $b)
+    function cmp_int($a, $b, $field)
     {
-        return ($a > $b) ? 1 : -1;
+        return ($a->getValue($field) > $b->getValue($field)) ? 1 : -1;
     }
 
 }
