@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/lib/Turba.php,v 1.59.4.44 2009/08/04 14:37:30 mrubinsk Exp $
+ * $Horde: turba/lib/Turba.php,v 1.59.4.48 2010-05-12 10:00:22 jan Exp $
  *
  * @package Turba
  */
@@ -94,10 +94,11 @@ class Turba {
      * return them in the user's preferred order.
      *
      * @param integer $permission  The PERMS_* constant to filter on.
+     * @param array $options       Any additional options.
      *
      * @return array  The filtered, ordered $cfgSources entries.
      */
-    function getAddressBooks($permission = PERMS_READ)
+    function getAddressBooks($permission = PERMS_READ, $options = array())
     {
         $addressbooks = array();
         foreach (array_keys(Turba::getAddressBookOrder()) as $addressbook) {
@@ -108,7 +109,7 @@ class Turba {
             $addressbooks = $GLOBALS['cfgSources'];
         }
 
-        return Turba::permissionsFilter($addressbooks, $permission);
+        return Turba::permissionsFilter($addressbooks, $permission, $options);
     }
 
     /**
@@ -221,19 +222,23 @@ class Turba {
     /**
      * Formats the name according to the user's preference.
      *
-     * @param Turba_Object $ob  The object to get a name from.
+     * @param Turba_Object $ob     The object to get a name from.
+     * @param string $name_format  The formatting. One of 'none', 'last_first'
+     *                             or 'first_last'.
      *
      * @return string  The formatted name, either "Firstname Lastname"
-     *                 or "Lastname, Firstname" depending on the user's
-     *                 preference.
+     *                 or "Lastname, Firstname" depending on $name_format or
+     *                 the user's preference.
      */
-    function formatName($ob)
+    function formatName($ob, $name_format = null)
     {
-        global $prefs;
-        static $name_format;
+        static $default_format;
 
-        if (!isset($name_format)) {
-            $name_format = $prefs->getValue('name_format');
+        if (!$name_format) {
+            if (!isset($default_format)) {
+                $default_format = $GLOBALS['prefs']->getValue('name_format');
+            }
+            $name_format = $default_format;
         }
 
         /* if no formatting, return original name */
@@ -329,10 +334,11 @@ class Turba {
      * @param array $in            The data we want filtered.
      * @param string $filter       What type of data we are filtering.
      * @param integer $permission  The PERMS_* constant we will filter on.
+     * @param array $options       Additional options.
      *
      * @return array  The filtered data.
      */
-    function permissionsFilter($in, $permission = PERMS_READ)
+    function permissionsFilter($in, $permission = PERMS_READ, $options = array())
     {
         $out = array();
 
@@ -344,6 +350,9 @@ class Turba {
             }
 
             if ($driver->hasPermission($permission)) {
+                if (!empty($options['require_add']) && !$driver->canAdd()) {
+                    continue;
+                }
                 $out[$sourceId] = $source;
             }
         }
@@ -398,7 +407,7 @@ class Turba {
                 // Default share?
                 if (empty($defaults[$params['source']])) {
                     $driver = &Turba_Driver::singleton($params['source']);
-                    if (!is_a($driver, 'PEAR_Error')) {
+                    if (!is_a($driver, 'PEAR_Error') && $driver->hasPermission(PERMS_EDIT)) {
                         $defaults[$params['source']] =
                             $driver->checkDefaultShare(
                                 $shares[$name],
@@ -455,6 +464,9 @@ class Turba {
 
         // Add vbooks now that all available address books are loaded.
         foreach ($vbooks as $name => $params) {
+            if (!isset($newSources[$params['source']])) {
+                continue;
+            }
             $newSources[$name] = array(
                 'title' => $shares[$name]->get('name'),
                 'type' => 'vbook',
