@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/lib/Views/Browse.php,v 1.12.2.9 2009/01/06 15:27:50 jan Exp $
+ * $Horde: turba/lib/Views/Browse.php,v 1.12.2.13 2010-08-14 17:19:51 jan Exp $
  *
  * Copyright 2000-2009 The Horde Project (http://www.horde.org/)
  *
@@ -201,7 +201,11 @@ class Turba_View_Browse {
                     foreach ($targetDriver->getCriteria() as $info_key => $info_val) {
                         if (!is_array($targetDriver->map[$info_key]) ||
                             isset($targetDriver->map[$info_key]['attribute'])) {
-                            $objAttributes[$info_key] = $object->getValue($info_key);
+                            $objectValue = $object->getValue($info_key);
+
+                            // Get 'data' value if object type is image, the
+                            // direct value in other case.
+                            $objAttributes[$info_key] = isset($GLOBALS['attributes'][$info_key]) && $GLOBALS['attributes'][$info_key]['type'] == 'image' ? $objectValue['load']['data'] : $objectValue;
                         }
                     }
                     unset($objAttributes['__owner']);
@@ -245,6 +249,10 @@ class Turba_View_Browse {
                         break;
                     }
                     $targetDriver = &Turba_Driver::singleton($targetSource);
+                    if (is_a($targetDriver, 'PEAR_Error')) {
+                        $notification->push(sprintf_("Could not load driver for %s", $targetSource), 'horde.error');
+                        break;
+                    }
                     $target = &$targetDriver->getObject($targetKey);
                     if (is_a($target, 'PEAR_Error')) {
                         $notification->push($target, 'horde.error');
@@ -253,6 +261,10 @@ class Turba_View_Browse {
                 } else {
                     $targetSource = $vars->get('targetAddressbook');
                     $targetDriver = &Turba_Driver::singleton($targetSource);
+                    if (is_a($targetDriver, 'PEAR_Error')) {
+                        $notification->push(sprintf_("Could not load driver for %s", $targetSource), 'horde.error');
+                        break;
+                    }
                 }
                 if (!empty($target) && $target->isGroup()) {
                     // Adding contact to an existing list.
@@ -378,7 +390,7 @@ class Turba_View_Browse {
                         $type_filter = array('__type' => 'Group');
                         break;
                     }
-                    $results = $driver->search($type_filter, $sortorder, 'AND', $columns);
+                    $results = $driver->search($type_filter, $sortorder, 'AND', $columns ? $columns : array('name'));
                     if (!is_object($results)) {
                         $notification->push(_("Failed to browse the directory"), 'horde.error');
                     } elseif (is_a($results, 'PEAR_Error')) {
