@@ -2,7 +2,7 @@
 /**
  * Turba external API interface.
  *
- * $Horde: turba/lib/api.php,v 1.120.2.70 2010/03/01 15:43:42 jan Exp $
+ * $Horde: turba/lib/api.php,v 1.120.2.71 2010-08-03 15:30:21 mrubinsk Exp $
  *
  * This file defines Turba's external API interface. Other applications can
  * interact with Turba through this API.
@@ -1638,9 +1638,9 @@ function _turba_getAllAttributeValues($field = '', $sources = array())
  */
 function _turba_listTimeObjectCategories()
 {
-    include dirname(__FILE__) . '/../config/attributes.php';
+    require_once dirname(__FILE__) . '/base.php';
+    global $cfgSources, $attributes;
     $categories = array();
-    include dirname(__FILE__) . '/../config/sources.php';
     foreach ($attributes as $key => $attribute) {
         if ($attribute['type'] == 'monthdayyear' &&
             !empty($attribute['time_object_label'])) {
@@ -1654,8 +1654,6 @@ function _turba_listTimeObjectCategories()
         }
     }
 
-
-
     return $categories;
 }
 
